#!/bin/bash
####################################################################
#
#
# ==== PBS part (resource manager part) =====
#PBS -l nodes=1:ppn=20
#PBS -l walltime=00:30:00
#PBS -N N2_exx
#
#
# ==== End of PBS part (resource manager part) =====

module purge
module use /scratch/igirotto/SMR3102/modulefiles
module load QE/6.0

cd ${PBS_O_WORKDIR}
export bin=${ESPRESSO_HOME}/bin
export PW_COMMAND=$bin/pw.x

## Choose the functional and the divergency treatment for the calculations
func="PBE0"   ## " PBE0" "HSE"
exxdiv_treatment="none"     ## "g-b" "none", "vcut_spherical" 
x_gamma_extrapolation='.FALSE.'

echo "Fucntional="$func " Divergence-Treatment="$exxdiv_treatment " GAMMA-extrapolation="$x_gamma_extrapolation

## Some consistency checks 
if [ "$exxdiv_treatment" = "vcut_spherical" ] ; then x_gamma_extrapolation=".FALSE." ; fi
if [ "$exxdiv_treatment" = "none" ] ; then x_gamma_extrapolation=".FALSE." ; fi
if [ "$x_gamma_extrapolation" = ".FALSE." ]; then extr="F"; else extr="T"; fi
if [ "$func" = "HSE" ] && [ "$exxdiv_treatment" = "vcut_spherical" ]; then echo "HSE and vcut_spherical are NOT compatible"; exit ; fi

echo "alat     Exx" > Exx_${func}_${exxdiv_treatment}_${extr}.dat

## Loop over the size of the simulation box
for alat in 12 14 16 18 20 24 28; do
echo "alat= " $alat

## Write the input file according to the specified parameters
cat > ${func}.in << EOF
&CONTROL
  calculation='scf',
  restart_mode='from_scratch',
  pseudo_dir= './pseudo/'
  outdir = './TMP/'
  prefix = "n2"
  wf_collect=.true.
/
&SYSTEM
  ecutrho =   320.0
  ecutwfc =    80.0
  ibrav = 1
  celldm(1) = $alat
  input_dft = "$func" 
  nat = 2
  nspin = 1
  ntyp = 1
  nbnd = 6
  exxdiv_treatment = '$exxdiv_treatment'
  x_gamma_extrapolation = $x_gamma_extrapolation

/
&ELECTRONS
    diagonalization='david'
    mixing_mode = 'plain'
    mixing_beta = 0.7
    conv_thr =  0.5d-8
/
ATOMIC_SPECIES
 N 14.007 N_ONCV_PBE-1.0.upf 

ATOMIC_POSITIONS angstrom
N 0.00000 0.00000 0.00000
N 0.00000 0.00000 1.12998

K_POINTS {gamma}
EOF

mpirun -np 8 $PW_COMMAND < ${func}.in > ${func}_${exxdiv_treatment}_${extr}_alat${alat}.out

echo $alat `grep "Fock energy"  ${func}_${exxdiv_treatment}_${extr}_alat${alat}.out | tail -1 | awk '{print $5}'` >> Exx_${func}_${exxdiv_treatment}_${extr}.dat 

done 
