#!/bin/bash

bindir="/scratch/colonna/ACFDT/espresso-6.0/bin/"

if [ ! -d PBEfix ] ; then mkdir PBEfix; fi

cd PBEfix
rm -fr TMP *out 
rm -fr res_pbefix.dat

for c in 2.4 2.5 2.6 2.75 2.8 2.9 3.1 3.3 3.5 3.8 4.2 4.6 5 5.5 6.0; do

## set a catoff in such way to have the same number of PW 
## the # of PW is proportional to Ecut^(3/2)*c
ecut=`echo "e(2./3.*l(4300/$c))" | bc -l`
echo $c $ecut

cat > pbefix.in << EOF
&control
    calculation='scf',
    restart_mode='from_scratch',
    prefix='graphite',
    pseudo_dir = '../pseudo/'
    outdir='./TMP'
    tstress = .true.,
    tprnfor = .true.,
/
&SYSTEM
    ibrav=  4,
    celldm(1) = 4.65255,
    celldm(3) = $c,
    nat=  4, 
    ntyp= 1,
    ecutwfc = $ecut,
/
&ELECTRONS
    diagonalization='david'
    mixing_mode = 'plain'
    mixing_beta = 0.7
    conv_thr =  0.5d-10
/
ATOMIC_SPECIES
    C  12.011  C_ONCV_PBE-1.0.upf
ATOMIC_POSITIONS {crystal}
C  0.00000000  0.00000000  0.25
C  0.00000000  0.00000000  0.75
C  0.33333333  0.66666667  0.25
C  0.66666667  0.33333333  0.75  
K_POINTS {automatic}
  6 6 4  1 1 1 
EOF

mpirun -np 8 $bindir/pw.x < pbefix.in > pbefix_c${c}.out

cc=`echo $c*4.65255 | bc -l`
echo $cc `grep ! pbefix_c${c}.out | awk '{print $5}'` >> res_pbefix.dat

done

cp res_pbefix.dat ../etot-pbefix_vs_c.dat
