#!/bin/bash
####################################################################
#
#
# ==== PBS part (resource manager part) =====
#
# The folloing indicates the nuber of requested nodes
# The number of ppn (processes per node) remains fixed to 20
#PBS -l nodes=1:ppn=20
#
# Total amount of time for which resources are requested HH:MM:SS
#PBS -l walltime=00:30:00
#
# Name of the Job s it will appear in the queue (qstat -u $USER)
#PBS -N graph_vdwdf
#
# Name of the dedicated resources. You must uncomment this entry when running 
# outside the didicated hours 
#PBS -q reserved3
#
#
# ==== End of PBS part (resource manager part) =====

module purge
module use /scratch/igirotto/SMR3102/modulefiles
module load QE/6.0

cd ${PBS_O_WORKDIR}
## Set the bin directory. You need to modify it!
export bin=${ESPRESSO_HOME}/bin
export PW_COMMAND=$bin/pw.x

## This script runs few scf calculations changing the c/a parameter (celldm(3))
## and stores the output files in a folder named accordingly to the functional.
## A file named etot-${funct}_vs_c.dat is authomatically generated in the working
## directory containing the c parameters (not the c/a ratio) and the total energies
## for each of the calculated stracture

## Create a directory to store the results if it does not already exist
if [ ! -d VDW-DF2 ] ; then mkdir VDW-DF2; fi

## Move into the folder and clean up
cd VDW-DF2
rm -fr TMP *out 
rm -fr res_vdw2.dat

## Loop over out-of-plane lattice parameter c (actually it is over the c/a ratio)
for c in 2.2 2.3 2.4 2.5 2.6 2.7 2.75 2.8 2.9 3.0 3.2 3.5 3.8 4.2 4.6 5.0 5.5 6.0 7.0 8.0 10.0; do

cat > vdw2.in << EOF
&control
    calculation='scf',
    restart_mode='from_scratch',
    prefix='graphite',
    pseudo_dir = '../pseudo/'
    outdir='./TMP'
    tstress = .true.,
    tprnfor = .true.,
/
&SYSTEM
    ibrav=  4,
    celldm(1) = 4.65255,
    celldm(3) = $c,
    nat=  4, 
    ntyp= 1,
    ecutwfc = 65,
    input_dft='vdw-df2'
/
&ELECTRONS
    diagonalization='david'
    mixing_mode = 'plain'
    mixing_beta = 0.7
    conv_thr =  0.5d-8
/
ATOMIC_SPECIES
    C  12.011  C_ONCV_PBE-1.0.upf
ATOMIC_POSITIONS {crystal}
C  0.00000000  0.00000000  0.25
C  0.00000000  0.00000000  0.75
C  0.33333333  0.66666667  0.25
C  0.66666667  0.33333333  0.75  
K_POINTS {automatic}
  6 6 4  1 1 1 
EOF

mpirun -np 20 $PW_COMMAND < vdw2.in > vdw2_c${c}.out

cc=`echo $c*4.65255 | bc -l`
echo $cc `grep ! vdw2_c${c}.out | awk '{print $5}'` >> res_vdw2.dat

done

cp res_vdw2.dat ../etot-vdw2_vs_c.dat
